Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4546)

Unified Diff: ash/common/wm/always_on_top_controller.h

Issue 2699033002: Replace WmWindowObserver with aura::WindowObserver. (Closed)
Patch Set: Check for null images in ShelfWindowWatcher. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/wallpaper/wallpaper_widget_controller.cc ('k') | ash/common/wm/always_on_top_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/common/wm/always_on_top_controller.h
diff --git a/ash/common/wm/always_on_top_controller.h b/ash/common/wm/always_on_top_controller.h
index cae200a8f777357dacc328f13da080417ded7ad9..bdf144635571b64b393b894ecc369621c165df08 100644
--- a/ash/common/wm/always_on_top_controller.h
+++ b/ash/common/wm/always_on_top_controller.h
@@ -8,17 +8,19 @@
#include <memory>
#include "ash/ash_export.h"
-#include "ash/common/wm_window_observer.h"
#include "base/macros.h"
+#include "ui/aura/window_observer.h"
namespace ash {
+
+class WmWindow;
class WorkspaceLayoutManager;
// AlwaysOnTopController puts window into proper containers based on its
// 'AlwaysOnTop' property. That is, putting a window into the worskpace
// container if its "AlwaysOnTop" property is false. Otherwise, put it in
// |always_on_top_container_|.
-class ASH_EXPORT AlwaysOnTopController : public WmWindowObserver {
+class ASH_EXPORT AlwaysOnTopController : public aura::WindowObserver {
public:
explicit AlwaysOnTopController(WmWindow* viewport);
~AlwaysOnTopController() override;
@@ -32,12 +34,12 @@ class ASH_EXPORT AlwaysOnTopController : public WmWindowObserver {
std::unique_ptr<WorkspaceLayoutManager> layout_manager);
private:
- // Overridden from WmWindowObserver:
- void OnWindowTreeChanged(WmWindow* window,
- const TreeChangeParams& params) override;
- void OnWindowPropertyChanged(WmWindow* window,
- WmWindowProperty property) override;
- void OnWindowDestroying(WmWindow* window) override;
+ // Overridden from aura::WindowObserver:
+ void OnWindowHierarchyChanged(const HierarchyChangeParams& params) override;
+ void OnWindowPropertyChanged(aura::Window* window,
+ const void* key,
+ intptr_t old) override;
+ void OnWindowDestroying(aura::Window* window) override;
WmWindow* always_on_top_container_;
« no previous file with comments | « ash/common/wallpaper/wallpaper_widget_controller.cc ('k') | ash/common/wm/always_on_top_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698